@@ -1,19 +1,28 @@
 from jsp_exp import Job
 from typing import List, Optional, Tuple
 
-from .utils import backward
-from .utils import forward
-from .utils.feasibility import has_schedule
-from .utils import jsp
+# from .utils import backward
+# from .utils import forward
+# from .utils.feasibility import has_schedule
+# from .utils import jsp
+
+
+from utils import backward
+from utils import forward
+from utils.feasibility import has_schedule
+from utils import jsp
+
+DEBUG = False
 
 
 def bsearch(job: Job, UB: int, fw: int, bu: int, bw: int):
+    # FIXHERE(2022/01/25): 逆になっていた！！！！！！
     if has_schedule(job, UB):
-        # shaving出来る
-        return backward.get_next_interval(bw + 1, fw)
-    else:
         # shaving出来ない
         return backward.get_next_interval(bu, bw)
+    else:
+        # shaving出来る
+        return backward.get_next_interval(bw + 1, fw)
 
 
 def shaving(r_list: List[int], p_list: List[int], q_list: List[int], UB: int) -> List[int]:
@@ -25,11 +34,17 @@ def shaving(r_list: List[int], p_list: List[int], q_list: List[int], UB: int) ->
         fu = fw = op.r
         org_q = op.q
         v = calc_q(op.p, org_q)
-        if fw >= v:
-            # 窓の左端と右端が同じ位置にあるとき対策（窓が[1, 1]みたいな状況）
-            # もっと賢い実装があるかも知れないが，時間もないし正直そこまで計さん時間大きくならないので取り敢えず無視
+        if op.r == v:
+            # 窓の左端と右端が一致している時は出来ない
             continue
+
+        if DEBUG:
+            print(f'forwardが開始します, 元のr={op.r}, 元のq={op.q}')
+            print(f"fu={fu}, fw={fw}")
+
         while True:
+            if DEBUG:
+                print(fu, fw)
             op.r, op.q = fu, calc_q(op.p, fw)
             if has_schedule(job, UB):
                 break
@@ -40,15 +55,31 @@ def shaving(r_list: List[int], p_list: List[int], q_list: List[int], UB: int) ->
                     break
                 else:
                     fu, fw = tu, tw
+        if DEBUG:
+            print('forwardが終了しました')
+            print(f"fu={fu}, fw={fw}")
+            print('-------------------------------')
+            print('backwardが開始します')
 
         # backward
         bu, bw = backward.get_next_interval(fu, fw)
+        if DEBUG:
+            print(f"bu={bu}, bw={bw}")
         while bu != bw:
             op.r, op.q = bu, calc_q(op.p, bw)
             bu, bw = bsearch(job, UB, fw, bu, bw)
+        if DEBUG:
+            print('backwardが終了しました')
+            print(f"bu={bu}, bw={bw}")
 
+        op.r, op.q = bu, calc_q(op.p, bw)
+        if DEBUG:
+            print("last test window", op.r, UB - op.p - op.q)
         op.r = bu if has_schedule(job, UB) else bu + 1
         op.q = org_q
+        if DEBUG:
+            print(f'終了後のr={op.r}, 終了後のq={op.q}')
+            print()
     if any(op.r > UB - op.p - op.q for op in job):
         # このような状況が生じるのかはよくわからないが，念の為
         return list()
